import com.vncrobot.VNCRobot;
import com.vncrobot.api.VNCRobotThread;

/**
 * LoadExample.java
 *
 * This is an example of load testing based on VNCRobot. For more information 
 * read the How To Use VNCRobot document at 
 * http://www.vncrobot.com/docs/examples/index.html#example5
 * 
 * (C) 2007, Robert Pes
 */
public class LoadExample {
    
    // Default number of threads.
    final static int DEFAULT_THREAD_COUNT = 50;
    
    // Main method.
    public static void main(String[] argv) {
        
        // Number of threads
        int threadCount = DEFAULT_THREAD_COUNT;
        
        // Password
        String password = null;
        
        // Script path
        String script = null;
        
        // Parse the program arguments. We expect an integer
        // indicating how many threads we will start followed by script name.
        // The last argument, VNC password, is not mandatory because some 
        // VNC servers can be configured not to require authentication.
        if (argv.length > 1 && argv.length < 4) {
            try {
                threadCount = Integer.parseInt(argv[0]);
                script = argv[1];
                if (argv.length > 2) {
                    password = argv[2];
                }
            } catch (NumberFormatException ex) {
                System.out.println("Invalid number of threads - default of "+DEFAULT_THREAD_COUNT+" will be used.");
            }
        } else {
            System.out.println("Usage: LoadExample <number_of_threads> <script_path> [<VNC_password>]");
            return;
        }
        
        // Thread arguments. They are identical with VNCRobot CLI options.
        String[] threadArguments;
        if (password == null) {
            threadArguments = new String[] {
                "--connect",        // Connect option
                "",                 // VNC host name and port - will be generated dynamically
                "--run",            // Run option
                script,             // Name and path of the script to run
                "--nodisplay"       // CLI execution mode option
            };
        } else {
            threadArguments = new String[] {
                "--connect",        // Connect option
                "",                 // VNC host name and port - will be generated dynamically
                "--run",            // Run option
                script,             // Name and path of the script to run
                "--nodisplay",      // CLI execution mode option
                "--password",       // Password option
                password            // Password
            };
        }
        
        // Create an instance of VNCRobot
        VNCRobot robot = new VNCRobot();

        VNCRobotThread runnable;
        Thread thread;
        
        // Loop for index from 1 to specified number of threads
        for (int i=1; i<=threadCount; i++) {
            
            // Populate the VNC host name and port in the thread arguments
            threadArguments[1] = "localhost:" + i;
            
            // Create a new automated thread and start it
            runnable = robot.createVNCRobotThread(threadArguments[1], threadArguments, System.out, false);
            thread = new Thread(runnable);
            thread.start();
        }
    }
}
